# TDS Control

A software package for the analysis and controller-design of time-delay systems.

## Bindings

Bindings to the TDS Control libary are provided for the following languages:
 - [Python](https://github.com/AppeltansPieter/TDSControl-python)
 - [Octave](https://github.com/AppeltansPieter/TDSControl-octave)

